@@ -16,7 +16,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: faac.h,v 1.33 2004/07/04 12:12:05 corrados Exp $
+ * $Id: faac.h,v 1.36 2009/01/25 18:50:32 menno Exp $
  */
 
 #ifndef _FAAC_H_
@@ -26,7 +26,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#ifdef WIN32
+#if defined(_WIN32) && !defined(__MINGW32__)
 # ifndef FAACAPI
 #  define FAACAPI __stdcall
 # endif
@@ -36,6 +36,8 @@ extern "C" {
 # endif
 #endif
 
+/* #pragma pack(push, 1) */
+
 typedef struct {
   void *ptr;
   char *name;
@@ -84,6 +86,9 @@ int FAACAPI faacEncEncode(faacEncHandle hEncoder, int32_t * inputBuffer, unsigne
 int FAACAPI faacEncClose(faacEncHandle hEncoder);
 
 
+
+/* #pragma pack(pop) */
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
